---
name: Bug report
about: Create a report to help us improve
title: ""
labels: ""
assignees: ""
---

## Describe the bug

A clear and concise description of what the bug is.

## Platform

Please provide details about the environment you are using, including the following:

- Interpreter version:
- Library version:

## Sample Code

Please include a minimal sample of the code that will (if possible) reproduce the bug in isolation

## Expected behavior

A clear and concise description of what you expected to happen.

## Observed behavior

What you see happening (error messages, stack traces, etc...)

## Additional context

Add any other context about the problem here.
